// ============================================================
// Project				:	CityRPG
// Author				:	Iban
// Description			:	Code that operates the Status GUI.
//								Document written in monospace
//								with 3-space tabbing.
//								
//								The actual code for initiation is in
//								unboxing.cs and does not execute
//								until the server has requested and been
//								accepted.
// ============================================================

// ============================================================
// Section 1 : Initiation
// ============================================================
$CRPG_C::Active	= false;
$CRPG_C::Path		= "Add-Ons/Client_CityRPG/";
$CRPG_C::Password	= "";
$CRPG_C::Version	= 3.2;

// If you're going to be using my code for ConnectArgs, take a look at this.
// It allows multiple mods to send name/version data over one paramter (parameter 8).
// If you follow the instructions in this and add it to your mod,
// everybody can live in harmony harmony harmony, oh love.
exec($CRPG_C::Path @ "scripts/Support_ModVersion.cs");

// Keybindings
$remapDivision[$remapCount]	= "CityRPG";
$remapName[$remapCount]			= "Open Admin GUI";
$remapCmd[$remapCount]			= "CityRPG_openAdmin";
$remapCount++;

$remapName[$remapCount]			= "Open Stats GUI";
$remapCmd[$remapCount]			= "CityRPG_openStats";
$remapCount++;

$remapName[$remapCount]			= "Reload Weapon";
$remapCmd[$remapCount]			= "CityRPG_Reload";
$remapCount++;

$remapName[$remapCount]			= "Toggle Status";
$remapCmd[$remapCount]			= "CityRPG_toggleStatus";
$remapCount++;

$remapName[$remapCount]			= "Toggle Villainy";
$remapCmd[$remapCount]			= "CityRPG_toggleVillainy";
$remapCount++;

// Add the cool green coloring.
JS_serverList.profile.fontColors[9] = "0 128 128 255";

// ============================================================
// Section 1 : clientCmds
// ============================================================
// Core ping-pong function that loads the rest of the GUI.
function clientCmdDisplayCRPGComponents()
{
	%name = getWord($ServerInfo::Name, 0);
	
	echo("Launched CityRPG Components.");
	$CRPG_C::Active = true;
	
	if($CRPG_C::Unboxed !$= $CRPG_C::Version)
		exec("./unboxing.cs");
	
	CityRPG_Status.setVisible(true);
	CityRPG_Status.fixPosition();
	CRPG_CreateDatumSO();
	
	commandToServer('CRPG_FirstResponse');
}

// Additional
function clientCmdDisplayCRPGBlackout(%fade, %time)
{
	if($CRPG_C::Active)
		ServerConnection.setBlackOut(%fade, %time);
}

function clientCmdDisplayCRPGError(%error)
{
	%error = strReplace(getTaggedString(%error), "CRPG_", "");
	
	if($pref::Video::useSmallPlantErrors && isFile($CRPG_C::Path @ "images/plantError_small/" @ %error @ ".png"))
	{
		cancel(HUD_PlantErrorSmall.hideSchedule);
		HUD_PlantErrorSmall.setVisible(true);
		HUD_PlantErrorSmall.setBitmap($CRPG_C::Path @ "images/plantError_small/" @ %error);
		HUD_PlantErrorSmall.hideSchedule = HUD_PlantErrorSmall.schedule(1000, "setVisible", false);
	}
	else if(isFile($CRPG_C::Path @ "images/plantError/" @ %error @ ".png"))
	{
		cancel(HUD_PlantError.hideSchedule);
		HUD_PlantError.setVisible(true);
		HUD_PlantError.setBitmap($CRPG_C::Path @ "images/plantError/" @ %error);
		HUD_PlantError.hideSchedule = HUD_PlantError.schedule(1000, "setVisible", false);
	}
	else
	{
		warn("\c1clientCmdDisplayCRPGError() : Could not find error file for \"" @ getTaggedString(%error) @ "\"!");
	}
}

function clientCmdDisplayCRPGGUI(%gui)
{
	if($CRPG_C::Active)
	{
		%gui = "CRPG_" @ %gui;
		
		if(isObject(%gui))
		{
			canvas.pushDialog(%gui);
		}
		else
		{
			error(%gui @ " does not exist.");
		}
	}
}

function clientCmdDisplayCRPGWelcome(%easter)
{
	if($CRPG_C::Active)
	{
		%file = $CRPG_C::Path @ "images/graphics/logo";
		
		if(isFile(%file @ "_" @ %easter @ ".png"))
			%file = %file @ "_" @ %easter;
		
		%ext	= getWord(getRes(), 0) SPC mCeil((getWord(getRes(), 0) / 1440) * 600);
		%pos	= "0" SPC mFloor(getWord(getRes(), 1) - getWord(%ext, 1) + 5);
		%logo	= new GuiBitmapCtrl()
		{
			profile				= "HUDBrickNameProfile";
			horizSizing			= "right";
			vertSizing			= "bottom";
			position				= %pos;
			extent				= %ext;
			minExtent			= "0 0";
			visible				= true;
			bitmap				= %file;
			wrap					= false;
			lockAspectRatio	= true;
			alignLeft			= true;
			overflowImage		= false;
			keepCached			= false;
		};
		
		PlayGUI.add(%logo);
		%logo.schedule(5000, "delete");
	}
}

function clientCmdSetCRPGStatus(%names1, %names2, %names3, %names4, %names5, %values1, %values2, %values3, %values4, %values5)
{	
	if($CRPG_C::Active)
	{
		// Interesting bug with changing maps in a non-dedicated server.
		if(!isObject(CRPG_Datum))
			clientCmdDisplayCRPGComponents();
		
		for(%a = 1; %a <= 5; %a++)
			%names = %names @ %names[%a];
			
		for(%a = 1; %a <= 5; %a++)
			%values = %values @ %values[%a];
		
		for(%a = 0; %a < getFieldCount(%names); %a++)
		{
			%name = getField(%names, %a);
			%value = getField(%values, %a);
			
			CRPG_Datum.setProperty(%name, %value);
		}
		
		CRPG_Datum.onUpdate();
	}
}

function clientCmdTagCRPGObject(%obj, %property, %value)
{
	if($CRPG_C::Active)
	{
		if(isObject(%obj))
		{
			eval(%obj @ "." @ %property SPC "=" SPC "\"" @ %value @ "\";");
		}
	}
}

// ============================================================
// Section 3 : CRPG_Datum Methods
// ============================================================
function CRPG_Datum::getProperty(%so, %name)
{
	return %so.var[%name];
}

function CRPG_Datum::onUpdate(%so)
{
	%so.hasData = true;
	
	// Alters GUIs n' shit.
	if(isObject(CRPG_Bank))
		adjustCityRPGBank();
	
	if(isObject(CityRPG_Status))
		adjustCityRPGStatus();
	
	if(isObject(CRPG_Stats))
		adjustCityRPGStats();
}

function CRPG_Datum::setProperty(%so, %name, %value)
{
	return (%so.var[%name] = %value);
}

// ============================================================
// Section 4 : Functions
// ============================================================
function CRPG_ChangeGender()
{
	commandToServer('Stats_ChangeGender');
}

function CRPG_Condense(%num)
{
	// Minimum int length is 4 digits.
	if(mAbs(%num) < 1000) return %num;
	
	// Prep the int for neutral comparison.
	%neg = %num < 0 ? -1 : 1;
	%num = mAbs(%num);
	%suffix = "";
	
	// Compare.
	// Find suffix.
	// Reduce.
	if(%num >= 1000000000)
	{
		%num /= 1000000000;
		%suffix = "b";
	}
	else if(%num >= 1000000)
	{
		%num /= 1000000;
		%suffix = "m";
	}
	else if(%num >= 1000)
	{
		%num /= 1000;
		%suffix = "k";
	}
	
	// Truncate float to 1 digit.
	%num = mFloatLength(%num, 1);
	
	// Remove floating 0.
	if(mFloor(%num - 0.1) < mFloor(%num))
		%num = mFloor(%num);
	
	// Reassign negative (if applicable)
	%num *= %neg;
	
	return %num @ %suffix;
}

function CRPG_CreateDatumSO()
{
	if(isObject(CRPG_Datum))
	{
		CRPG_Datum.delete();
	}
	
	new scriptObject(CRPG_Datum)
	{
		hasData = false;
	};
}

function CRPG_DeleteDatumSO()
{
	if(isObject(CRPG_Datum))
	{
		CRPG_Datum.delete();
	}
}

function CRPG_Pop()
{
	CRPG_AdminButton.setVisible(false);
	CityRPG_Status_NoData.setVisible(true);
	CityRPG_Status_Data.setVisible(false);
	CityRPG_Status.setVisible(false);
	HUD_AmmoNameBG.setVisible(false);
	HUD_CrimeEnabled.setVisible(false);
	Crosshair.setBitmap("base/client/ui/crossHair");
	
	CRPG_DeleteDatumSO();
	CRPG_DeleteJobOpSO();
	deleteVariables("$CRPG::*");
	deleteVariables("$CRPG_Temp::");
	$CRPG_C::Active = false;
	$CRPG_C::RuinedWrenchGUI = false;
}

function CRPG_ReportBug()
{
	if(isObject(RTB_ModManager))
	{
		Canvas.pushDialog(RTB_ModManager);
		RTBMM_ModsView_Init();
		RTBMM_ModsView_Report(537);
		RTBMM_Report_Summary.setText("Put a short description of the bug in here.");
		RTBMM_Report_Description.setText("Please explain in this box what the bug is and how you came across it.");
	}
}

function CRPG_TagFilter(%message)
{
	%tags = "[%CRPGTAG:AWARD_PATH]";
	%reps = $CRPG_C::Path @ "images/badges/" @ $Pref::Gui::ChatSize;
	
	for(%a = 0; %a < getLineCount(%tags); %a++)
	{
		%tag = getLine(%tags, %a);
		%rep = getLine(%reps, %a);
		
		%message = strReplace(%message, %tag, %rep);
	}
	
	return %message;
}

function getIflFrame(%node, %name)
{
	%file = "base/data/shapes/player/" @ %node @ ".ifl";
	
	if(isFile(%file))
	{
		%name = stripTrailingSpaces(fileBase(%name));
		
		if(%name !$= "")
		{
			%fo = new FileObject() {};
			%fo.openForRead(%file);
			
			%hasFound = false;
			%lineNum = 0;
			
			while(!%fo.isEOF())
			{
				%line = %fo.readLine();
				%thisDecal = stripTrailingSpaces(fileBase(%line));
				
				if(%thisDecal $= %name)
				{
					%hasFound = true;
					break;
				}
				else
				{
					%lineNum++;
				}
			}
			
			%fo.close();
			%fo.delete();
			
			if(%hasFound)
			{
				return %lineNum;
			}
			else
			{
				return 0;
			}
		}
		else
		{
			return 0;
		}
	}
	else
	{
		echo("\c2getIflFrame(\"" @ %node @ "\", \"" @ %name @ "\") : You did not supply a proper IFL file name to read from.");
		return 0;
	}
}

// ============================================================
// Section 4 : Package
// ============================================================
package CRPG_Client_Main
{
	function Canvas::popDialog(%canvas, %gui)
	{
		%result = parent::popDialog(%canvas, %gui);
		
		switch(%gui.getID())
		{
			case BrickSelectorDlg.getID() :
				if($CRPG_C::Active)
					CityRPG_Status.setVisible(true);
			
			case AdminGUI.getID() :
				CRPG_AdminButton.setVisible(false);
		}
		
		return %result;
	}
	
	function Canvas::pushDialog(%canvas, %gui)
	{
		%result = parent::pushDialog(%canvas, %gui);
		
		if($CRPG_C::Active && isObject(%gui))
		{
			switch(%gui.getID())
			{
				case BrickSelectorDlg.getID() :
					CityRPG_Status.setVisible(false);
				
				case AdminGUI.getID() :
					if($IamAdmin == 2)
						CRPG_AdminButton.setVisible(true);
			}
		}
		
		return %result;
	}
	
	function Canvas::setContent(%canvas, %gui)
	{
		%result = parent::setContent(%canvas, %gui);
		
		if($CRPG_C::Active && isObject(%gui))
		{
			switch(%gui.getID())
			{
				case PlayGUI.getID() :
					if($CRPG_C::Active && $CRPG_C::NoobDisplay)
					{
						Canvas.pushDialog(CRPG_Noob);
					}
			}
		}
		
		return %result;
	}
	
	function disconnectedCleanup()
	{
		%result = parent::disconnectedCleanup();
		CRPG_Pop();
		return %result;
	}
	
	function handleLoadMapPictureMessage(%message, %picture, %fallback)
	{
		if(%picture $= "Add-Ons/Map_CityRPG/CityRPG")
		{
			%res = getRes();
			%x = getWord(%res, 0);
			%y = getWord(%res, 1);
			%ratio = mFloatLength(%x / %y, 1);
			
			switch(%ratio)
			{
				case 1.3:
					%picture = $CRPG_C::Path @ "images/graphics/CityRPG_4_3";
				case 1.5:
					%picture = $CRPG_C::Path @ "images/graphics/CityRPG_4_3";
				case 1.6:
					%picture = $CRPG_C::Path @ "images/graphics/CityRPG_16_10";
				case 1.7:
					%picture = $CRPG_C::Path @ "images/graphics/CityRPG_16_10";
				default: 
					%picture = $CRPG_C::Path @ "images/graphics/CityRPG_4_3";
			}
		}
		
		return parent::handleLoadMapPictureMessage(%message, %picture, %fallback);
	}
	
	function MessageBoxOK(%title, %text)
	{
		if(!$CRPG_C::Active)
			return parent::MessageBoxOK(%title, %text);
		
		Canvas.pushDialog(CRPG_MBOK);
		CRPG_MBOK_Frame.setText(%title);
		MBSetText(CRPG_MBOK_Text, CRPG_MBOK_Frame, %text);
	}
	
	function onChatMessage(%message, %idk1, %idk2)
	{
		if($CRPG_C::Active)
			%message = CRPG_TagFilter(%message);
		
		return parent::onChatMessage(%message, %idk1, %idk2);
	}
	
	function resetCanvas()
	{
		%result = parent::resetCanvas();
		
		if($CRPG_C::Active)
		{
			CityRPG_Status.fixPosition();
			
			if(isObject(HUD_CrimeEnabled))
				HUD_CrimeEnabled.position = getWords(vectorSub(HUD_SuperShift.position, "0 37"), 0, 1);
			
			if(isObject(HUD_AmmoNameBG))
				HUD_AmmoNameBG.position = getWords(vectorAdd(HUD_ToolNameBG.position SPC 0, "0 18 0"), 0, 1);
		}
		
		return %result;
	}
	
	function ServerSO::serialize(%so)
	{
      %serialized = parent::serialize(%so);
      
		// This will only replace black (uncolorized) with my special color.
		// Passworded / Full still takes priority.
		if(getWord(%so.name, 0) $= "CityRPG's" || getWords(%so.name, 0, 1) $= "Iban's CityRPG")
		{
			// Remove black special coloring (it defaults to black, anyways).
			%serialized = strreplace(%serialized, "\c0", "");
			
			// Set \c9 infront of everything.
			// If RTB or anything else put another color code before this,
			// the second color code (e.g. not \c9) will take effect.
			%serialized = "\c9" @ %serialized;
		}
		
      return %serialized;
	}
	
	function wrenchVehicleSpawnDlg::onWake(%gui)
	{
		%result = parent::onWake(%canvas, %gui);
		
		if($CRPG_C::Active)
		{
			if($IamAdmin < 2)
			{
				$CRPG_C::RuinedWrenchGUI = true;
				
				WrenchVehicleSpawn_Vehicles.clear();
				%vehicles = CRPG_Datum.var["garage"];
				%vcount = getWordCount(%vehicles);
				
				if(%vcount)
				{
					for(%a = 0; %a < %vcount; %a++)
					{
						%vehicle = getWord(%vehicles, %a);
						
						if(isObject(%vehicle))
							WrenchVehicleSpawn_Vehicles.add(%vehicle.uiName, %vehicle.getID());
					}
					
					WrenchVehicleSpawn_Vehicles.sort();
					WrenchVehicleSpawn_Vehicles.addFront("None", 0);
				}
				else
				{
					WrenchVehicleSpawn_Vehicles.add("No Vehicles in Garage", 0);
					WrenchVehicleSpawn_Vehicles.setSelected(0);
				}
			}
			else if($CRPG_C::RuinedWrenchGUI)
			{
				// So Badspot can bitch at me if I break something.
				echo("CityRPG - Re-Assembling Vehicle Wrench Dialog List.");
				// Remove the temp property so this process does not happen twice.
				$CRPG_C::RuinedWrenchGUI = false;
				
				WrenchVehicleSpawn_Vehicles.clear();
				
				// This is a pretty uber leet hax.
				// Repopulate the wrench dialog.
				
				// In another player'ss server, ServerConnection group has the datablocks and DataBlockGroup has none.
				// If our DataBlockGroup has members, we want to scan through it instead of SC.
				%group = DataBlockGroup.getCount() ? DataBlockGroup : ServerConnection;
				
				for(%a = 0; %a < %group.getCount(); %a++)
				{
					%db = %group.getObject(%a);
					
					// It's so fucking easy, a caveman could do it!
					// If %db is rideable and has a name, add it.
					if(%db.rideAble && %db.uiName !$= "")
						WrenchVehicleSpawn_Vehicles.add(%db.uiName, %db.getID());
					
					// .position only appears on instantiated objects.
					// Datablocks are not instances.
					// We load datablocks before our first object
					// so once we find a position property, we know we're at
					// the end of the datablock list.
					else if(%db.position !$= "")
						break;
				}
				
				WrenchVehicleSpawn_Vehicles.sort();
				WrenchVehicleSpawn_Vehicles.addFront("None", 0);
			}
		}
		
		return %result;
	}
};

activatePackage(CRPG_Client_Main);