// ============================================================
// Project				:	CityRPG
// Author				:	Iban
// Description			:	Code that operates the Bank GUI.
// ============================================================

// ============================================================
// Section 1 : Object Initiation
// ============================================================
while(isObject(CRPG_Bank))
{
	CRPG_Bank.delete();
}

exec($CRPG_C::Path @ "guis/bank.gui");

// ============================================================
// Section 2 : Functions
// ============================================================
function adjustCityRPGBank()
{
	// Data
	%bank			= CRPG_Datum.var["Bank"];
	%debt			= CRPG_Datum.var["Debt"];
	%education	= CRPG_Datum.var["Education"];
	%money		= CRPG_Datum.var["Money"];
	%student		= CRPG_Datum.var["Student"];
	
	// Blocker
	CRPG_Bank_LoanBlocker.setVisible(%debt == 0 && %student == 0 && %education < 5 ? false : true);
	CRPG_Bank_EnrollBlocker.setVisible(%debt == 0 && %student == 0 && %education < 6 ? false : true);
	
	// Labels
	CRPG_Bank_Balance.setText("<color:000000>$" @ %bank);
	CRPG_Bank_Debt.setText((%debt > 0 ? "<color:ff0000>$" : "<color:000000>$") @ %debt);
	CRPG_Bank_Cash.setText("<color:000000>$" @ %money);
	
	// Text Boxes
	CRPG_Bank_Deposit.setValue(%money);
	CRPG_Bank_Withdraw.setValue("0");
	CRPG_Bank_PayOff.setValue(%money);
}

// All of these checks (and then some) are server-side, too.
function CRPG_Bank::deposit(%gui)
{
	if(isObject(CRPG_Datum))
	{
		%amount = CRPG_Bank_Deposit.getValue();
		
		if(mFloatLength(%amount, 0) $= %amount && %amount > 0)
		{
			if(CRPG_Datum.var["Money"] >= %amount)
			{
				commandToServer('Bank_Deposit', %amount);
				MessageBoxOK("Just a Moment...", "Communicating with the Server.\n\nHold tight.");
			}
			else
			{
				MessageBoxOK("Does Not Compute", "You don't have that much money.");
			}
		}
		else
		{
			MessageBoxOK("Does Not Compute", "That's not a valid number, bro.");
		}
	}
	else
	{
		MessageBoxOK("Does Not Compute", "CityRPG is still trying to fetch your profile from the database.\n\nHang tight.");
	}
}

function CRPG_Bank::enroll(%gui)
{
	if(isObject(CRPG_Datum))
	{
		if(CRPG_Datum.var["Education"] < 6 && !CRPG_Datum.var["Student"])
		{
			if(CRPG_Datum.var["Debt"] <= 0)
			{
				commandToServer('Bank_Enroll');
				MessageBoxOK("Just a Moment...", "Communicating with the Server.\n\nHold tight.");
			}
			else
			{
				MessageBoxOK("Does Not Compute", "Sorry! You cant enroll until you've paid off last semester's student debts.");
			}
		}
		else if(CRPG_Datum.var["Student"])
		{
			MessageBoxOK("Does Not Compute", "You are already enrolled.");
		}
		else if(CRPG_Datum.var["Education"] >= 6)
		{
			MessageBoxOK("Does Not Compute", "Sorry! You cannot take a loan for a degree that high.");
		}
	}
	else
	{
		MessageBoxOK("Does Not Compute", "CityRPG is still trying to fetch your profile from the database.\n\nHang tight.");
	}
}

function CRPG_Bank::payOff(%gui)
{
	if(isObject(CRPG_Datum))
	{
		%amount = CRPG_Bank_PayOff.getValue();
		
		if(mFloatLength(%amount, 0) $= %amount && %amount > 0)
		{
			if(CRPG_Datum.var["Debt"] > 0)
			{
				commandToServer('Bank_PayOff', %amount);
				MessageBoxOK("Just a Moment...", "Communicating with the Server.\n\nHold tight.");
			}
			else
			{
				MessageBoxOK("Does Not Compute", "You don't have any debt.");
			}
		}
		else
		{
			MessageBoxOK("Does Not Compute", "That's not a valid number, bro.");
		}
	}
	else
	{
		MessageBoxOK("Does Not Compute", "CityRPG is still trying to fetch your profile from the database.\n\nHang tight.");
	}
}

function CRPG_Bank::takeLoan(%gui)
{
	if(isObject(CRPG_Datum))
	{
		if(CRPG_Datum.var["Education"] <= 4 && !CRPG_Datum.var["Student"])
		{
			if(CRPG_Datum.var["Debt"] <= 0)
			{
				commandToServer('Bank_TakeLoan');
				MessageBoxOK("Just a Moment...", "Communicating with the Server.\n\nHold tight.");
			}
			else
			{
				MessageBoxOK("Does Not Compute", "Sorry! You cant take out another loan until you've paid off the one you already have.");
			}
		}
		else if(CRPG_Datum.var["Student"])
		{
			MessageBoxOK("Does Not Compute", "You are already enrolled.");
		}
		else if(CRPG_Datum.var["Education"] >= 5)
		{
			MessageBoxOK("Does Not Compute", "Sorry! You cannot take a loan for a degree that high.");
		}
	}
	else
	{
		MessageBoxOK("Does Not Compute", "CityRPG is still trying to fetch your profile from the database.\n\nHang tight.");
	}
}

function CRPG_Bank::withdraw(%gui)
{
	if(isObject(CRPG_Datum))
	{
		%amount = CRPG_Bank_Withdraw.getValue();
		
		if(mFloatLength(%amount, 0) $= %amount && %amount > 0)
		{
			if(CRPG_Datum.var["Bank"] > 0)
			{
				commandToServer('Bank_Withdraw', %amount);
				MessageBoxOK("Just a Moment...", "Communicating with the Server.\n\nHold tight.");
			}
			else
			{
				MessageBoxOK("Does Not Compute", "You don't have any money in the bank.");
			}
		}
		else
		{
			MessageBoxOK("Does Not Compute", "That's not a valid number, bro.");
		}
	}
	else
	{
		MessageBoxOK("Does Not Compute", "CityRPG is still trying to fetch your profile from the database.\n\nHang tight.");
	}
}