// ============================================================
// Project				:	CityRPG
// Author				:	Iban
// Description			:	Code that operates the Status GUI.
// ============================================================

// ============================================================
// Section 1 : Object Initiation
// ============================================================
while(isObject(CRPG_MBOK))
	CRPG_MBOK.delete();

exec($CRPG_C::Path @ "guis/mbok.gui");

while(isObject(HUD_CrimeEnabled))
	HUD_CrimeEnabled.delete();

if(!isObject(HUD_CrimeEnabled))
{
	new GuiBitmapCtrl(HUD_CrimeEnabled)
	{
		profile = "GuiDefaultProfile";
		horizSizing = "left";
		vertSizing = "bottom";
		position = getWords(vectorSub(HUD_SuperShift.position, "0 37"), 0, 1);
		extent = "184 37";
		minExtent = "8 2";
		visible = "0";
		bitmap = $CRPG_C::Path @ "images/graphics/crime_enabled";
		wrap = "0";
		lockAspectRatio = "0";
		alignLeft = "0";
		overflowImage = "0";
		keepCached = "0";
	};
	
	PlayGUI.add(HUD_CrimeEnabled);
}

if(!isObject(CRPG_Hail_Chief_Sound))
{
	new AudioProfile(CRPG_Hail_Chief_Sound)
	{
		filename		= $CRPG_C::Path @ "sounds/hail_to_the_chief.wav";
		description	= AudioGui;
		preload		= true;
	};
}

// ============================================================
// Section 2 : Functions
// ============================================================
function CityRPG_Reload(%down)
{
	if($CRPG_C::Active && %down)
		commandToServer('Command_Reload');
}

function CityRPG_toggleVillainy(%down)
{
	if($CRPG_C::Active && %down)
		commandToServer('Command_ToggleVillainy');
}

function clientCmdCRPGCashChange(%value, %cash, %bank, %debt)
{
	if($CRPG_C::Active)
	{
		%value = mFloor(%value);
		
		CRPG_Datum.var["MONEY"]	= %cash;
		CRPG_Datum.var["BANK"]	= %bank;
		CRPG_Datum.var["DEBT"]	= %debt;
		adjustCityRPGStatus();
		
		%value = "<just:right>" @ (%value < 0 ? ("\c0$" @ mAbs(%value)) : ("\c2$" @ %value));
		
		%xExt = 250;
		%yExt = 48;
		
		%xPos = getWord(getRes(), 0) - %xExt;
		%yPos = getWord(getRes(), 1) - %yExt;
		
		%element = new GuiMLTextCtrl()
		{
			profile				= "CRPGCashNoticeProfile";
			horizSizing			= "right";
			vertSizing			= "bottom";
			position				= %xPos SPC %yPos;
			extent				= %xExt SPC %yExt;
			minExtent			= "0 0";
			visible				= true;
			lineSpacing			= 2;
			allowColorChars	= true;
			maxChars				= -1;
			text					= %value;
			maxBitmapHeight	= -1;
			selectable			= false;
		};
		
		if(isObject($LastCashChange))
		{
			cancel($LastCashChange.moveSchedule);
			PlayGUI.moveCashNotice($LastCashChange, 500, -150, 50, 1); 
			%time = 500;
		}
		else
			%time = 1000;
		
		PlayGUI.add(%element);
		%element.moveSchedule = PlayGUI.schedule(%time, "moveCashNotice", %element, 500, -150, 50, 1); 
		$LastCashChange = %element;
	}
}

function clientCmdCRPGMayorTheme()
{
	alxPlay(CRPG_Hail_Chief_Sound);
}

function clientCmdCRPGPlasticChange(%value, %plastic)
{
	if($CRPG_C::Active)
	{
		%value = mFloor(%value);
		
		CRPG_Datum.var["PLASTIC"] = %plastic;
		adjustCityRPGStatus();
		
		%value = "<just:right>" @ (%value >= 0 ? "\c5" : "\c9") @ %value;
		
		%xExt = 250;
		%yExt = 48;
		
		%xPos = getWord(getRes(), 0) - %xExt;
		%yPos = getWord(getRes(), 1) - %yExt;
		
		%element = new GuiMLTextCtrl()
		{
			profile				= "CRPGCashNoticeProfile";
			horizSizing			= "right";
			vertSizing			= "bottom";
			position				= %xPos SPC %yPos;
			extent				= %xExt SPC %yExt;
			minExtent			= "0 0";
			visible				= true;
			lineSpacing			= "2";
			allowColorChars	= true;
			maxChars				= "-1";
			text					= %value;
			maxBitmapHeight	= "-1";
			selectable			= false;
		};
		
		if(isObject($LastCashChange))
		{
			cancel($LastCashChange.moveSchedule);
			PlayGUI.moveCashNotice($LastCashChange, 500, -150, 50, 1); 
			%time = 500;
		}
		else
			%time = 1000;
		
		PlayGUI.add(%element);
		%element.moveSchedule = PlayGUI.schedule(%time, "moveCashNotice", %element, 500, -150, 50, 1); 
		$LastCashChange = %element;
	}
}

function clientCmdCRPGVillainy(%villain)
{
	if($CRPG_C::Active)
	{
		HUD_CrimeEnabled.setVisible(%villain);
		
		if(%villain)
		{
			HUD_CrimeEnabled.position = getWords(vectorSub(HUD_SuperShift.position, "0 37"), 0, 1);
			Crosshair.setBitmap($CRPG_C::Path @ "images/ui/crossHairEvil");
		}
		else
		{
			Crosshair.setBitmap("base/client/ui/crossHair");
		}
	}
}

function PlayGUI::moveCashNotice(%gui, %element, %time, %yMovement, %steps, %currStep)
{
	if(isObject(%element))
	{
		if($LastCashChange == %element)
			$LastCashChange = 0;
		
		cancel(%element.movementSchedule);
		
		%move = mFloor(%yMovement / %steps);
		
		%xLoc = getWord(%element.position, 0);
		%yLoc = getWord(%element.position, 1);
		%newYLoc = %yLoc + %move;
		
		%element.position = %xLoc SPC %newYLoc;
		
		if(%currStep < %steps)
		{
			%element.moveSchedule = %gui.schedule(%time / %steps, "moveCashNotice", %element, %time, %yMovement, %steps, %currStep + 1);
		}
		else
		{
			%element.delete();
		}
	}
}
