// ============================================================
// Project				:	CityRPG
// Author				:	Iban
// Description			:	Code that operates the Stats GUI.
// ============================================================

// ============================================================
// Section 1 : Object Initiation
// ============================================================
while(isObject(CRPG_Stats))
	CRPG_Stats.delete();

// Stats
exec($CRPG_C::Path @ "guis/stats.gui");

// Clear
CRPG_Avatar.setEmpty();
// Name
CRPG_Avatar.dynamicObject = "CRPG_Avatar_Object";
// Object Creation and Sequences
CRPG_Avatar.setObject(CRPG_Avatar.dynamicObject, "base/data/shapes/player/m.dts", "", 0);

// ============================================================
// Section 2 : Functions
// ============================================================
function adjustCityRPGStats()
{
	// Fiscal
	CRPG_Stats_OnHand.setValue("$" @ CRPG_Datum.var["MONEY"]);
	CRPG_Stats_InBank.setValue("$" @ CRPG_Datum.var["BANK"]);
	CRPG_Stats_InDebt.setValue((CRPG_Datum.var["DEBT"] ? "<color:ff0000>" : "") @ "$" @ CRPG_Datum.var["DEBT"]);
	CRPG_Stats_Networth.setValue("$" @ (CRPG_Datum.var["BANK"] + CRPG_Datum.var["MONEY"] - CRPG_Datum.var["DEBT"]));
	
	// Job
	CRPG_Stats_Job.setValue("<just:center>" @ CRPG_Datum.var["JOBNAME"]);
	CRPG_Stats_TicksDue.setValue("<just:center>" @ (CRPG_Datum.var["WORKHOURS"] ? CRPG_Datum.var["WORKHOURS"] SPC "Hours Due" : ""));
	CRPG_Stats_Plastic.setValue("<just:center>" @ CRPG_Datum.var["PLASTIC"] SPC "Chunks");
	CRPG_Stats_RefPlastic.setValue("<just:center>" @ CRPG_Datum.var["REFPLASTIC"] SPC "Plastic");
	
	// Education
	CRPG_Stats_Education.setValue("<just:center>Tier" SPC CRPG_Datum.var["EDUCATION"] SPC "Diploma");
	CRPG_Stats_Student.setValue("<just:center>" @ (CRPG_Datum.var["STUDENT"] ? "Enrolled" : "Not Enrolled"));
	CRPG_Stats_Reincarnate.setValue("<just:center>" @ CRPG_Datum.var["REINCARNATE"] ? "You're a Reincarnate!" : "");
	
	// EXP
	%suffix = " EXP";
	CRPG_Stats_Bum.setValue(CRPG_Condense(CRPG_Datum.var["expBum"]) @ %suffix);
	CRPG_Stats_Drone.setValue(CRPG_Condense(CRPG_Datum.var["expDrone"]) @ %suffix);
	CRPG_Stats_Labor.setValue(CRPG_Condense(CRPG_Datum.var["expLabor"]) @ %suffix);
	CRPG_Stats_Shopkeep.setValue(CRPG_Condense(CRPG_Datum.var["expStore"]) @ %suffix);
	CRPG_Stats_Law.setValue(CRPG_Condense(CRPG_Datum.var["expLaw"]) @ %suffix);
	CRPG_Stats_Political.setValue(CRPG_Condense(CRPG_Datum.var["expPC"]) @ %suffix);
	
	// Gender
	if(CRPG_Datum.var["GENDER"] == 2)
		CRPG_Stats_GenderBtn.setBitmap($CRPG_C::Path @ "images/ui/btnMale");
	else
		CRPG_Stats_GenderBtn.setBitmap($CRPG_C::Path @ "images/ui/btnFem");
	
	// Beliefs
	CRPG_Stats.adjustAvatar();
	CRPG_Stats.adjustBeliefs();
	CRPG_Stats.renderJobOps();
}

function CityRPG_openStats(%key)
{
	if($CRPG_C::Active)
	{
		if(%key)
		{
			canvas.pushDialog(CRPG_Stats);
		}
	}
}

function CRPG_CreateJobOpSO()
{
	if(isObject(CRPG_JobOps))
		CRPG_JobOps.delete();
	
	return new ScriptObject(CRPG_JobOps)
	{
		numCategories = 0;
		numOps = 0;
	};
}

function CRPG_DeleteJobOpSO()
{
	if(isObject(CRPG_JobOps))
		CRPG_JobOps.delete();
}

function CRPG_JobOps_FilterParams(%parameters)
{
	// Filter Tags
	%tagID = "[%STAT:";
	
	while((%tagLoc = strPos(%parameters, %tagID)) >= 0)
	{
		%tagEnd = strPos(%parameters, "]", %tagLoc);
		%tagLen = strLen(%tagID);
		
		if(%tagEnd >= 0)
		{
			%tag = getSubStr(%parameters, %tagLoc + %tagLen, %tagEnd - (%tagLoc + %tagLen));
			%value = CRPG_Datum.var[%tag];
			%parameters = strReplace(%parameters, %tagID @ %tag @ "]", %value);
		}
	}
	
	return %parameters;
}

function CRPG_JobOps_ValidateInt(%ctrl)
{
   if(%ctrl.getValue() $= "")
      return;
   if(%ctrl.getValue() $= "-")
      return;      
      
   %value = mFloatLength(%ctrl.getValue(),0);
   
   if(%value > %ctrl.fieldMax)
      %value = %ctrl.fieldMax;
      
   if(%value < %ctrl.fieldMin)
      %value = %ctrl.fieldMin;
      
   %ctrl.setValue(%value);
}

function CRPG_JobOpValid(%range)
{
	%words = getWordCount(%range);
	
	if(%words)
	{
		%type = getWord(%range, 0);
		%param = getWords(%range, 1, getWordCount(%range) - 1);
		%paramCount = getWordCount(%param);
		
		switch$(%type)
		{
			case "bool":
				%paramNeed = 1;
				
				if(%paramCount == %paramNeed)
					return true;
			
			case "int":
				%paramNeed = 3;
				
				if(%paramCount == %paramNeed)
					return true;
			
			case "list":
				%paramNeed = 2;
				
				if(%paramCount % 2 == 0)
					return true;
				
			case "float":
				%paramNeed = 4;
				
				if(%paramCount == %paramNeed)
					return true;
				
			case "string":
				%paramNeed = 1;
				
				if(%paramCount == %paramNeed)
					return true;
			
			case "text":
				return true;
			
			case "button":
				%paramNeed = 2;
				
				if(%paramCount >= %paramNeed)
					return true;
		}
		
		echo("\c2Type \"" @ %type @ "\" requires " @ %paramNeed @ ", but server only provided " @ %paramCount @ ".");
	}
	else
		echo("\c2Range provided does not have at least 1 word.");
	
	return false;
}

function CRPG_Stats::adjustAvatar(%gui)
{
	CRPG_Avatar.setSequence(CRPG_Avatar.dynamicObject, 0, "headup", 0);
	CRPG_Avatar.setSequence(CRPG_Avatar.dynamicObject, 1, "run", 0.85);
	CRPG_Avatar.setOrbitDist(4.34);
	CRPG_Avatar.setCameraRot(0.25, 0, 4.25);
	
	if(CRPG_Avatar.parts > 0)
	{
		%gui.hideAllNodes();
		%gui.adjustAvatarNodes();
		%gui.adjustAvatarColors();
	}
	else
	{
		%gui.applyDefaultPrefs();
	}
}

function CRPG_Stats::adjustAvatarColors(%gui)
{
	if(CRPG_Avatar.parts > 0)
	{
		CRPG_Avatar.setNodeColor(CRPG_Avatar.dynamicObject, "headskin", $pref::Avatar::HeadColor);
		
		for(%i = 0; %i < CRPG_Avatar.parts; %i++)
		{
			%color = CRPG_Avatar.color[%i];
			
			if(%color $= "skin")
			{
				%color = $pref::Avatar::HeadColor;
			}
			
			CRPG_Avatar.setNodeColor(CRPG_Avatar.dynamicObject, CRPG_Avatar.part[%i], %color);
		}
	}
}

function CRPG_Stats::adjustAvatarNodes(%gui)
{
	CRPG_Avatar.unHideNode(CRPG_Avatar.dynamicObject, "headskin");
	
	if(CRPG_Avatar.parts > 0)
	{
		for(%i = 0; %i < CRPG_Avatar.parts; %i++)
		{
			CRPG_Avatar.unHideNode(CRPG_Avatar.dynamicObject, CRPG_Avatar.part[%i]);
		}
	}
	
	CRPG_Avatar.setIflFrame(CRPG_Avatar.dynamicObject, "face", getIflFrame("face", $Pref::Avatar::FaceName));
	CRPG_Avatar.setIflFrame(CRPG_Avatar.dynamicObject, "decal", getIflFrame("decal", CRPG_Avatar.decal));
}

function CRPG_Stats::adjustBeliefs(%gui)
{
	// Arrows
	%enabled = CRPG_Datum.var["beliefChangeTime"] > 0 ? false : true;
	
	// Bullets
	for(%a = 1; %a <= 5; %a++)
	{
		%belief = "";
		
		switch(%a)
		{
			case 1: %belief = "Order";
			case 2: %belief = "Peace";
			case 3: %belief = "Commercial";
			case 4: %belief = "Night";
			case 5: %belief = "Tradition";
		}
		
		%leftArrow = "CRPG_Belief_Arrow_Left_" @ %a;
		%rightArrow = "CRPG_Belief_Arrow_Right_" @ %a;
		
		%leftArrow.setActive(%enabled);
		%rightARrow.setActive(%enabled);
		
		if(%enabled)
			if(CRPG_Datum.var["belief" @ %belief] == 1)
				%leftArrow.setActive(0);
			else if(CRPG_Datum.var["belief" @ %belief] == 11)
				%rightArrow.setActive(0);
		
		for(%b = 1; %b <= 11; %b++)
		{
			%bullet = "CRPG_Belief_Bullet_" @ %a @ "_" @ %b;
			
			if(CRPG_Datum.var["belief" @ %belief] != %b)
				%bullet.setBitmap($CRPG_C::Path @ "images/icons/Icon_Bullet_White");
			else
				%bullet.setBitmap($CRPG_C::Path @ "images/icons/Icon_Bullet_Black");
		}
	}
}

function CRPG_Stats::applyDefaultPrefs(%gui)
{
	%gui.hideAllNodes();
	
	%nodeCount = 0;
	
	%node[%nodeCount++] = "headSkin" TAB "1 1 0 1";
	%node[%nodeCount++] = "chest" TAB "1 1 1 1";
	%node[%nodeCount++] = "LArm" TAB "1 1 1 1";
	%node[%nodeCount++] = "RArm" TAB "1 1 1 1";
	%node[%nodeCount++] = "LHand" TAB "1 1 0 1";
	%node[%nodeCount++] = "RHand" TAB "1 1 0 1";
	%node[%nodeCount++] = "pants" TAB "0 0 0.8 1";
	%node[%nodeCount++] = "LShoe" TAB "0.2 0.2 0.2 1";
	%node[%nodeCount++] = "RShoe" TAB "0.2 0.2 0.2 1";
	
	for(%i = 1; %i <= %nodeCount; %i++)
	{
		CRPG_Avatar.unHideNode(CRPG_Avatar.dynamicObject, getField(%node[%i], 0));
		CRPG_Avatar.setNodeColor(CRPG_Avatar.dynamicObject, getField(%node[%i], 0), getField(%node[%i], 1));
	}
	
	CRPG_Avatar.setIflFrame(CRPG_Avatar.dynamicObject, "face", 0);
	CRPG_Avatar.setIflFrame(CRPG_Avatar.dynamicObject, "decal", 0);
}

function CRPG_Stats::applyForJob(%gui)
{
	if(isObject(CRPG_Datum))
	{
		%id = CRPG_Stats_Jobs.getSelectedId();
		%text = CRPG_Stats_Jobs.getRowTextById(%id);
		
		if(%text !$= "")
		{
			%name = getField(%text, 1);
			%edu = getField(%text, 4);
			%id = getField(%text, 5);
			
			if(CRPG_Datum.var["Education"] >= %edu)
			{
				if(%cost > 0)
					MessageBoxOkCancel("You are about to be a" SPC %name, "Are you sure you want to spend $" @ %cost SPC "to apply for the job \"" @ %name @ "\"?\n\nThis cannot be undone and if you apply for another job you will not get that money back.", "commandToServer('Stats_ApplyForJob', " @ %id @ ");", "");
				else
					MessageBoxOkCancel("You are about to be a" SPC %name, "Are you sure you want to give up your current job for this new position?\n\nThink carefully.\nThis action cannot be undone.", "commandToServer('Stats_ApplyForJob', " @ %id @ ");", "");
			}
			else
			{
				MessageBoxOK("Does Not Compute", "You are not educated enough for" SPC %name @ ".");
			}
		}
		else
		{
			MessageBoxOK("Does Not Compute", "Select a job in the upper right and then click this button to apply for it.\n\nIf no jobs are visible, you are currently in the only role you can play!");
		}
	}
	else
	{
		MessageBoxOK("Does Not Compute", "CityRPG is still trying to fetch your profile from the database.\n\nHang tight.");
	}
}

function CRPG_Stats::getJobOpElement(%gui, %category, %op)
{
	if(isObject(CRPG_JobOps))
	{
		%range = CRPG_JobOps.opRange[%category, %op];
		
		if(%range !$= "")
		{
			if(CRPG_JobOpValid(%range))
			{
				%name = "CRPG_JobOpsOp_" @ %category @ "_" @ %op;
				
				%type = getWord(%range, 0);
				%param = CRPG_JobOps_FilterParams(getWords(%range, 1, getWordCount(%range) - 1));
				%paramCount = getWordCount(%param);
				
				for(%a = 0; %a < %paramCount; %a++)
					%param[%a] = getWord(%param, %a);
				
				switch$(%type)
				{
					case "bool":
						%element = new GuiCheckBoxCtrl(%name)
						{
							profile = "CRPGCheckbBoxProfile";
							text = " ";
							position = "100 7";
							extent = "140 16";
							
							horizSizing = "right";
							vertSizing = "bottom";
							minExtent = "8 2";
							visible = "1";
							groupNum = "-1";
							buttonType = "ToggleButton";
						};
						%element.setValue(%param[0] ? true : false);
					
					case "int":
						%element = new GuiTextEditCtrl(%name)
						{
							profile = "CRPGTextEditProfile";
							maxLength = strLen(%param[1]);
							fieldDefault = %param[2];
							fieldMin = %param[0];
							fieldMax = %param[1];
							position = "100 7";
							extent = "140 30";
							command = "CRPG_JobOps_ValidateInt(" @ %name @ ");";
							
							horizSizing = "right";
							vertSizing = "bottom";
							minExtent = "8 2";
							visible = "1";
							historySize = "0";
							password = "0";
							tabComplete = "0";
							sinkAllKeyEvents = "0";
						};
						%element.setValue(%element.fieldDefault);
						
					case "list":
						
					case "string":
						%element = new GuiTextEditCtrl(%name)
						{
							profile = "CRPGTextEditProfile";
							maxLength = strLen(%param[0]);
							position = "100 7";
							extent = "140 30";
							
							horizSizing = "right";
							vertSizing = "bottom";
							minExtent = "8 2";
							visible = "1";
							historySize = "0";
							password = "0";
							tabComplete = "0";
							sinkAllKeyEvents = "0";
						};
						%element.setValue(%param[1]);
					
					case "text":
						%element = new GuiTextCtrl(%name)
						{
							profile = "GuiTextProfile";
							position = "100 7";
							extent = "140 16";
							
							horizSizing = "right";
							vertSizing = "bottom";
							minExtent = "8 2";
							visible = "1";
							text = "\c2" @ %param;
							maxLength = "255";
						};
					
					case "button":
						%element = new GuiBitmapButtonCtrl(%name) {
							profile = "CRPGButtonProfile";
							position = "100 5";
							extent = "75 20";
							
							command = "commandToServer('" @ %param[0] @ "');";
							text = getWords(%range, 2, getWordCount(%range) - 1);
							
							horizSizing = "left";
							vertSizing = "top";
							minExtent = "8 2";
							visible = true;
							groupNum = "-1";
							buttonType = "PushButton";
							bitmap = "Add-Ons/Client_CityRPG/images/ui/button2";
							lockAspectRatio = "0";
							alignLeft = "0";
							overflowImage = "0";
							mKeepCached = "0";
							mColor = "255 255 255 255";
						};
				}
				
				if(isObject(%element))
					return %element;
				else
					%failText = "Did not properly render Element. Odd.";
			}
			else
				%failText = "Range for [" @ %category @ "," SPC %op @ "] is invalid.";
		}
		else
			%failText = "Range for [" @ %category @ "," SPC %op @ "] does not exist.";
	}
	else
		%failText = "CRPG_JobsOps ScriptObject does not even exist.";

	return new GuiTextCtrl()
	{
		profile = "GuiTextProfile";
		position = "100 7";
		extent = "140 16";
		
		horizSizing = "right";
		vertSizing = "bottom";
		minExtent = "8 2";
		visible = "1";
		text = "\c2" @ %failText;
		maxLength = "255";
	};
}

function CRPG_Stats::hideAllNodes(%gui)
{
	%nodeCount = 0;
	
	%node[%nodeCount++] = "plume";
	%node[%nodeCount++] = "triPlume";
	%node[%nodeCount++] = "septPlume";
	%node[%nodeCount++] = "Visor";
	
	%node[%nodeCount++] = "helmet";
	%node[%nodeCount++] = "pointyHelmet";
	%node[%nodeCount++] = "flareHelmet";
	%node[%nodeCount++] = "scoutHat";
	%node[%nodeCount++] = "bicorn";
	%node[%nodeCount++] = "copHat";
	%node[%nodeCount++] = "knitHat";
	
	%node[%nodeCount++] = "chest";
	%node[%nodeCount++] = "femchest";
	
	%node[%nodeCount++] = "pants";
	%node[%nodeCount++] = "skirtHip";
	
	%node[%nodeCount++] = "armor";
	%node[%nodeCount++] = "bucket";
	%node[%nodeCount++] = "cape";
	%node[%nodeCount++] = "pack";
	%node[%nodeCount++] = "quiver";
	%node[%nodeCount++] = "tank";
	
	%node[%nodeCount++] = "epaulets";
	%node[%nodeCount++] = "epauletsRankA";
	%node[%nodeCount++] = "epauletsRankB";
	%node[%nodeCount++] = "epauletsRankC";
	%node[%nodeCount++] = "epauletsRankD";
	%node[%nodeCount++] = "ShoulderPads";
	
	%node[%nodeCount++] = "LArm";
	%node[%nodeCount++]  = "LArmSlim";
	
	%node[%nodeCount++]  = "LHand";
	%node[%nodeCount++]  = "LHook";
	
	%node[%nodeCount++]  = "RArm";
	%node[%nodeCount++]  = "RArmSlim";
	
	%node[%nodeCount++]  = "RHand";
	%node[%nodeCount++]  = "RHook";
	
	%node[%nodeCount++]  = "pants";
	%node[%nodeCount++]  = "skirtHip";
	
	%node[%nodeCount++]  = "LShoe";
	%node[%nodeCount++]  = "LPeg";
	
	%node[%nodeCount++]  = "RShoe";
	%node[%nodeCount++]  = "RPeg";
	
	%node[%nodeCount++]  = "SkirtTrimLeft";
	%node[%nodeCount++]  = "SkirtTrimRight";
	%node[%nodeCount++]  = "LSki";
	%node[%nodeCount++]  = "RSki";
	
	for(%i = 1; %i <= %nodeCount; %i++)
	{
		CRPG_Avatar.hideNode(CRPG_Avatar.dynamicObject, %node[%i]);
	}
}

function CRPG_Stats::onWake(%gui)
{
	if($CRPG_C::Active)
	{
		%gui.adjustAvatar();
		%gui.adjustBeliefs();
		%gui.renderJobOps();
		
		commandToServer('Stats_GetOutfit');
		//commandToServer('Stats_GetJobOps');
		commandToServer('Stats_GetJobs');
		
		if(CRPG_Datum.var["GENDER"] != 2)
			CRPG_Stats_GenderBtn.setBitmap($CRPG_C::Path @ "images/ui/btnFem");
		else
			CRPG_Stats_GenderBtn.setBitmap($CRPG_C::Path @ "images/ui/btnMale");
	}
}

function CRPG_Stats::renderJobOps(%gui)
{
	while(CRPG_Stats_JobOps_Container.getCount())
		CRPG_Stats_JobOps_Container.getObject(0).delete();
	
	if(!isObject(CRPG_JobOps))
	{
		CRPG_Stats_JobOp_Btn.setVisible(false);
		
		if(%gui.currPane == 3)
			%gui.setPane(0);
		
		return;
	}
	
	CRPG_Stats_JobOp_Btn.setVisible(true);
	
	%offset = "0";
	
	// Categories
	for(%a = 0; %a < CRPG_JobOps.numCategories; %a++)
	{
	  %element = new GuiSwatchCtrl()
	  {
			profile = "GuiDefaultProfile";
			horizSizing = "right";
			vertSizing = "bottom";
			position = "0" SPC %offset;
			extent = "524 30";
			minExtent = "8 2";
			visible = "1";
			color = "0 0 0 50";

			new GuiTextCtrl()
			{
				profile = "RTBMM_MainText";
				horizSizing = "right";
				vertSizing = "center";
				position = "5 6";
				extent = "200 18";
				minExtent = "8 2";
				visible = "1";
				text = "\c1" @ CRPG_JobOps.category[%a];
				maxLength = "255";
			};
		};
		
		CRPG_Stats_JobOps_Container.add(%element);
		%offset += 30;
		
		// Ops
		for(%b = 0; %b < CRPG_JobOps.numOpsIn[%a]; %b++)
		{
			%element = new GuiSwatchCtrl()
			{
				profile = "GuiDefaultProfile";
				horizSizing = "right";
				vertSizing = "bottom";
				position = "0" SPC %offset;
				extent = "524 29";
				minExtent = "8 2";
				visible = "1";
				color = "0 0 0" SPC (%b % 2 == 0 ? 10 : 0);

				new GuiTextCtrl()
				{
					profile = "GuiTextProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "5 5";
					extent = "66 18";
					minExtent = "8 2";
					visible = "1";
					text = (CRPG_JobOps.op[%a, %b] !$= "-1") ? "\c2" @ CRPG_JobOps.op[%a, %b] @ ":" : "";
					maxLength = "255";
				};
			};
			
			%element.add(%gui.getJobOpElement(%a, %b));
			CRPG_Stats_JobOps_Container.add(%element);
			%offset += 30;
		}
		
		%offset += 2;
	}
	
	%x = getWord(CRPG_Stats_JobOps_Scroll.extent, 0);
	%y = mClamp(%offset, getWord(CRPG_Stats_JobOps_Scroll.extent, 1), %offset);
	CRPG_Stats_JobOps_Container.extent = %x SPC %y;
}

function CRPG_Stats::sendJobOps(%gui)
{
	%count = 0;
	%data = "";
	
	for(%a = 0; %a < CRPG_JobOps.numCategories; %a++)
	{
		for(%b = 0; %b < CRPG_JobOps.numOpsIn[%a]; %b++)
		{
			%name = "CRPG_JobOpsOp_" @ %a @ "_" @ %b;
			
			if(isObject(%name))
			{
				if(%count)
					%data = %data NL %a TAB %b TAB %name.getValue();
				else
					%data = %a TAB %b TAB %name.getValue();
				
				%count++;
			}
		}
	}
	
	for(%a = 0; strLen(%data); %a++)
	{
		%packet[%a] = getSubStr(%data, 0, 255);
		%data = getSubStr(%data, 255, strLen(%data));
	}
	
	commandToServer('Stats_UpdateJobOps', %packet[0], %packet[1], %packet[2], %packet[3], %packet[4], %packet[5]);
}

function CRPG_Stats::setBeliefDown(%gui, %id)
{
	// Changing the -1 to, say, -2 will not change anything.
	// This is clamped server-side.
	commandToServer('Stats_ChangeBelief', %id, -1);
}

function CRPG_Stats::setBeliefUp(%gui, %id)
{
	commandToServer('Stats_ChangeBelief', %id, 1);
}

function CRPG_Stats::setPane(%gui, %id)
{
	%id = mClamp(%id, 0, %id);
	
	if(%id < %gui.numPanes)
	{
		for(%a = 0; %a < %gui.numPanes; %a++)
		{
			if(%id == %a)
			{
				%gui.tab[%a].setBitmap("Add-Ons/Client_CityRPG/images/ui/Tab1use");
				%gui.pane[%a].setVisible(true);
			}
			else
			{
				%gui.tab[%a].setBitmap("Add-Ons/Client_CityRPG/images/ui/Tab1");
				%gui.pane[%a].setVisible(false);
			}
		}
	}
	
	%gui.currPane = %id;
}

function CRPG_Stats::sortList(%gui, %list, %col)
{
	%list.sort(%col, %list.sort);
	%list.sort = !%list.sort;
	return %list.sort;
}

function CRPG_Stats::sortNumList(%gui, %list, %col)
{
	%list.sortNumerical(%col, %list.numSort);
	%list.numSort = !%list.numSort;
	return %list.numSort;
}


function Event_setBeliefFrames::onMouseEnter(%this)
{
	if(%this.leftFrame !$= "")
		CRPG_Stats_Frame_Left.setBitmap(%this.leftFrame);
	
	if(%this.rightFrame !$= "")
		CRPG_Stats_Frame_Right.setBitmap(%this.rightFrame);
	
	return parent::onMouseEnter(%this);
}

function Event_setBeliefFrames::onMouseLeave(%this)
{
	CRPG_Stats_Frame_Left.defaultSched = CRPG_Stats_Frame_Left.schedule(250, "setBitmap", $CRPG_C::Path @ "images/beliefs/default_left");
	CRPG_Stats_Frame_Right.defaultSched = CRPG_Stats_Frame_Right.schedule(250, "setBitmap", $CRPG_C::Path @ "images/beliefs/default_right");
}

// ============================================================
// Section 3 : ClientCmds
// ============================================================
// Job Operations
function clientCmdStats_ClearJobOps()
{
	CRPG_DeleteJobOpSO();
}

function clientCmdStats_AddJobOpCat(%category)
{
	if(!isObject(CRPG_JobOps))
		CRPG_CreateJobOpSO();
	
	CRPG_JobOps.category[mFloor(CRPG_JobOps.numCategories)] = %category;
	CRPG_JobOps.numCategories++;
}

function clientCmdStats_AddJobOpOp(%category, %name, %range)
{
	if(!isObject(CRPG_JobOps))
		CRPG_CreateJobOpSO();
	
	if(!CRPG_JobOpValid(%range))
	{
		echo("\c2 +- Job Op failed because Range is invalid. Category:" SPC %category @ ", Name:" SPC %name @ ", Range:" SPC %range);
		return;
	}
	
	CRPG_JobOps.op[mFloor(%category), mFloor(CRPG_JobOps.numOpsIn[%category])] = %name;
	CRPG_JobOps.opRange[mFloor(%category), mFloor(CRPG_JobOps.numOpsIn[%category])] = %range;
	CRPG_JobOps.numOps++;
	CRPG_JObOps.numOpsIn[%category]++;
}

// Other
function clientCmdStats_SetJobs(%colors, %names, %costs, %edus, %ids)
{
	CRPG_Stats_Jobs.clear();
	
	for(%i = 0; %i < getFieldCount(%names); %i++)
	{
		%color = collapseEscape("\\c" @ mClamp(getField(%colors, %i), 0, 9));
		%name	= getField(%names, %i);
		%cost	= getField(%costs, %i);
		%edu	= getField(%edus, %i);
		%id	= getField(%ids, %i);
		
		if(%name !$= "")
			CRPG_Stats_Jobs.addRow(CRPG_Stats_Jobs.rowCount(), %color TAB %name TAB "$" TAB %cost TAB %edu TAB %id);
	}
	
	CRPG_Stats_Jobs.sort(4);
}

function clientCmdStats_SetLots(%names, %costs)
{
	CRPG_Stats_Lots.clear();
	
	for(%i = 0; %i < getFieldCount(%names); %i++)
	{
		%name	= getField(%names, %i);
		%cost	= getField(%costs, %i);
		
		if(%name !$= "")
			CRPG_Stats_Lots.addRow(CRPG_Stats_Lots.rowCount(), %name TAB "$" TAB %cost);
	}
}

function clientCmdStats_SetOutfit(%parts, %decal, %nodes, %color)
{
	CRPG_Avatar.parts = %parts;
	CRPG_Avatar.decal = %decal;
	
	for(%i = 0; %i < %parts; %i++)
	{
		CRPG_Avatar.part[%i] = getField(%nodes, %i);
		CRPG_Avatar.color[%i] = getField(%color, %i);
	}
	
	CRPG_Stats.hideAllNodes();
	CRPG_Stats.adjustAvatarNodes();
	CRPG_Stats.adjustAvatarColors();
}

function clientCmdStats_SetVehicles(%names, %costs)
{
	CRPG_Stats_Vehicles.clear();
	
	for(%i = 0; %i < getFieldCount(%names); %i++)
	{
		%name	= getField(%names, %i);
		%cost	= getField(%costs, %i);
		
		if(%name !$= "")
			CRPG_Stats_Vehicles.addRow(CRPG_Stats_Vehicles.rowCount(), %name TAB "$" TAB %cost);
	}
}

function clientCmdStats_SetWeapons(%names, %costs)
{
	CRPG_Stats_Weapons.clear();
	
	for(%i = 0; %i < getFieldCount(%names); %i++)
	{
		%name	= getField(%names, %i);
		%cost	= getField(%costs, %i);
		
		if(%name !$= "")
			CRPG_Stats_Weapons.addRow(CRPG_Stats_Weapons.rowCount(), %name TAB "$" TAB %cost);
	}
}
