// ============================================================
// Project				:	CityRPG
// Author				:	Iban
// Description			:	Code that operates the Vehicle GUI.
// ============================================================

// ============================================================
// Section 1 : Object Initiation
// ============================================================
while(isObject(CRPG_Vehicles))
{
	CRPG_Vehicles.delete();
}

exec($CRPG_C::Path @ "guis/vehicle.gui");

// ============================================================
// Section 2 : Functions
// ============================================================
function CRPG_Vehicles::adjust(%gui, %increase)
{
	%window = (%gui.getCount() ? %gui.getObject(0) : 0);
	
	if(isObject(%window))
	{
		%x = getWord(%window.extent, 0);
		%y = getWord(%window.extent, 1) + %increase;
		
		if(%y > 380)
		{
			%increase = %y - 380;
			%y = 380;
		}
		
		if(%y < 380)
		{
			%increase++;
			%gui.schedule(32, "adjust", %increase);
		}
		
		%window.extent = %x SPC %y;
		
		%x = getWord(%window.position, 0);
		%y = getWord(%window.position, 1) - mFloor(%increase / 2);
		
		%window.position = %x SPC %y;
		
	}
}

function CRPG_Vehicles::buyVehicle(%gui)
{
	if(isObject(%gui.crpgSelection))
	{
		%name = %gui.crpgSelection.crpgName;
		%cost = %gui.crpgSelection.crpgCost;
		%id = %gui.crpgSelection.crpgDb;
		
		MessageBoxOkCancel("You are about to buy a " SPC %name,
		"You are about to spend" SPC %cost SPC "to buy a(n)" SPC %name @ ".\nThis action cannot be undone.\n\nAre you SURE you want to do this?",
		"commandToServer('Vehicles_BuyVehicle', \"" @ %id @ "\");",
		"Canvas.popDialog(CRPG_Vehicles);");
	}
}

function CRPG_Vehicles::onWake(%gui)
{
	%gui.crpgSelection = "";
	%window = (%gui.getCount() ? %gui.getObject(0) : 0);
	
	if(isObject(%window))
	{
		%window.extent = getWord(%window.extent, 0) SPC "182";
		%window.position = getWords(vectorScale(vectorSub(getRes(), %window.extent), 0.5), 0, 1);
		
		if(CRPGV_Control.getCount())
		{
			CRPGV_Blocker.setVisible(false);
			CRPGV_Control.extent = (CRPGV_Control.getCount() * 98) SPC "96";
			
			for(%a = 0; %a < CRPGV_Control.getCount(); %a++)
				CRPGV_Control.getObject(%a).getObject(1).setVisible(false);
		}
	}
}

function CRPG_Vehicles::selectBlock(%gui, %block)
{
	if(isObject(%block) && (!isObject(%gui.crpgSelection) || %gui.crpgSelection.getID() != %block.getID()))
	{
		if(isObject(%gui.crpgSelection))
			%gui.crpgSelection.getObject(1).setVisible(false);
		
		%gui.crpgSelection = %block.getID();
		%gui.crpgSelection.getObject(1).setVisible(true);
		
		CRPGV_Display.setBitmap(%block.crpgBitmap);
		CRPGV_Name.setText(%block.crpgName);
		CRPGV_Corp.setText(%block.crpgCorp);
		CRPGV_Price.setText(%block.crpgCost);
		CRPGV_Description.setText(%block.crpgDesc);
		
		for(%a = 1; %a <= 5; %a++)
			eval("CRPGV_Star_" @ %a @ ".setVisible(" @ (%a <= %block.crpgStar) @ ");");
		
		CRPG_Vehicles.adjust(1);
	}
}

// ============================================================
// Section 3 : ClientCmds
// ============================================================
function clientCmdVehicle_AddVehicle(%db, %name, %corp, %price, %rating, %desc)
{
	if($CRPG_C::Active)
	{
		%name = trim(stripMLControlChars(trim(%name)));
		%corp = trim(stripMLControlChars(trim(%corp)));
		%price = mFloor(%price);
		%rating = mClampF(mFloor(%rating), 0, 5);
		%desc = trim(stripMLControlChars(trim(%desc)));
		
		if(%name $= "")
			%name = "Vehicle";
		
		if(%corp $= "")
			%corp = "Unknown";
		
		if(%price < 0)
			%price = 0;
		
		%price = "$" @ %price;
		
		%guiName = "CRPGV_Block_" @ strReplace(%name, " ", "_");
		
		if(!isObject(%guiName))
		{
			%block = new GuiBitmapCtrl(%guiName) {
				profile = "BlockDefaultProfile";
				horizSizing = "right";
				vertSizing = "bottom";
				position = (CRPGV_Control.getCount() * 98) SPC "0";
				extent = "96 96";
				minExtent = "8 2";
				visible = "1";
				bitmap = "base/client/ui/brickicons/brickiconbg";
				wrap = "0";
				lockAspectRatio = "0";
				alignLeft = "0";
				overflowImage = "0";
				keepCached = "1";
				
				crpgDb = %db;
				crpgName = %name;
				crpgCorp = %corp;
				crpgCost = %price;
				crpgStar = %rating;
				crpgDesc = %desc;
				crpgBitmap = $CRPG_C::Path @ "images/vehicles/Icon_Vehicle_" @ strReplace(%name, " ", "_");
				
				// Vehicle Icon
				new GuiBitmapCtrl() {
					profile = "BlockDefaultProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "0 0";
					extent = "96 96";
					minExtent = "8 2";
					visible = "1";
					wrap = "0";
					lockAspectRatio = "1";
					alignLeft = "0";
					overflowImage = "0";
					keepCached = "1";
					bitmap = $CRPG_C::Path @ "images/vehicles/Icon_Vehicle_" @ strReplace(%name, " ", "_");
				};
				new GuiBitmapCtrl() {
					profile = "BlockDefaultProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "0 0";
					extent = "96 96";
					minExtent = "8 2";
					visible = "0";
					bitmap = "base/client/ui/brickicons/brickIconActive";
					wrap = "0";
					lockAspectRatio = "0";
					alignLeft = "0";
					overflowImage = "0";
					keepCached = "1";
				};
				new GuiBitmapButtonCtrl() {
					profile = "CRPGButtonProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "0 0";
					extent = "96 96";
					minExtent = "8 2";
					visible = "1";
					text = " ";
					groupNum = "-1";
					buttonType = "PushButton";
					bitmap = "base/client/ui/brickicons/brickIconBtn";
					lockAspectRatio = "0";
					alignLeft = "0";
					overflowImage = "0";
					mKeepCached = "0";
					mColor = "255 255 255 255";
					
					command = "CRPG_Vehicles.selectBlock(" @ %guiName @ ");";
					altCommand = "CRPG_Vehicles.selectBlock(" @ %guiName @ ");";
				};
				
				// Label
				new GuiTextCtrl() {
					profile = "HUDBSDNameProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "0 78";
					extent = "96 18";
					minExtent = "8 2";
					visible = "1";
					text = %name;
					maxLength = "255";
				};
			};
			
			CRPGV_Control.add(%block);
		}
	}
}

function clientCmdVehicle_Clear()
{
	while(CRPGV_Control.getCount())
		CRPGV_Control.getObject(0).delete();
}

function clientCmdVehicle_Close()
{
	Canvas.popDialog(CRPG_Vehicles);
}