// ============================================================
// Project				:	CityRPG
// Author				:	Iban
// Description			:	Code that operates the Voting GUI.
// ============================================================

// ============================================================
// Section 1 : Object Initiation
// ============================================================
while(isObject(CRPG_Vote))
{
	CRPG_Vote.delete();
}

exec($CRPG_C::Path @ "guis/vote.gui");

// ============================================================
// Section 2 : Functions
// ============================================================
function CRPG_Vote::adjustAvatar(%gui, %id)
{
	if(!isObject(%av = "CRPG_Vote_Avatar_" @ %id))
		return false;
	
	//%av.setSequence(%av.dynamicObject, 0, "headup", 0);
	//%sav.setSequence(%av.dynamicObject, 1, "run", 0.85);
	%av.setOrbitDist(6.5);
	
	%rotX	= 0.25;
	%rotY	= 0.00;
	
	switch(%id)
	{
		case 1: %rotZ = 4.00;
		case 2: %rotZ = 3.50;
		case 3: %rotZ = 3.15;
		case 4: %rotZ = 2.70;
		case 5: %rotZ = 2.20;
	}
	
	%av.setCameraRot(%rotX, %rotY, %rotZ);
	
	if(%av.parts > 0)
	{
		%gui.hideAllNodes(%id);
		%gui.adjustAvatarNodes(%id);
		%gui.adjustAvatarColors(%id);
	}
	else
	{
		//%gui.applyDefaultPrefs(%id);
	}
	
	%gui.adjustAvatarTitles(%id);
	
	return true;
}

function CRPG_Vote::adjustAvatarColors(%gui, %id)
{
	if(!isObject(%av = "CRPG_Vote_Avatar_" @ %id))
		return false;
	
	if(%av.parts > 0)
	{
		for(%i = 0; %i < %av.parts; %i++)
		{
			%color = %av.color[%i];
			%av.setNodeColor(%av.dynamicObject, %av.part[%i], %color);
		}
	}
}

function CRPG_Vote::adjustAvatarNodes(%gui, %id)
{
	if(!isObject(%av = "CRPG_Vote_Avatar_" @ %id))
		return false;
	
	%av.unHideNode(%av.dynamicObject, "headskin");
	
	if(%av.parts > 0)
	{
		for(%i = 0; %i < %av.parts; %i++)
		{
			%av.unHideNode(%av.dynamicObject, %av.part[%i]);
		}
	}
	
	%av.setIflFrame(%av.dynamicObject, "face", getIflFrame("face", %av.face));
	%av.setIflFrame(%av.dynamicObject, "decal", getIflFrame("decal", %av.decal));
}

function CRPG_Vote::adjustAvatarTitles(%gui, %id)
{
	if(!isObject(%av = "CRPG_Vote_Avatar_" @ %id))
		return false;
	
	%incumbent = "CRPG_Vote_Avatar_Incumbent_" @ %id;
	%name = "CRPG_Vote_Avatar_Text_" @ %id;
	
	if(%av.parts > 0)
	{
		%incumbent.setVisible(%av.incumbent);
		%name.setVisible(true);
		%name.setText(%av.name);
	}
	else
	{
		%incumbent.setVisible(false);
		%name.setVisible(false);
	}
	
}

function CRPG_Vote::applyDefaultPrefs(%gui, %id)
{
	if(!isObject(%av = "CRPG_Vote_Avatar_" @ %id))
		return false;
	
	%gui.hideAllNodes(%id);
	
	%nodeCount = 0;
	
	%node[%nodeCount++] = "headSkin" TAB "1 1 0 1";
	%node[%nodeCount++] = "chest" TAB "1 1 1 1";
	%node[%nodeCount++] = "LArm" TAB "1 1 1 1";
	%node[%nodeCount++] = "RArm" TAB "1 1 1 1";
	%node[%nodeCount++] = "LHand" TAB "1 1 0 1";
	%node[%nodeCount++] = "RHand" TAB "1 1 0 1";
	%node[%nodeCount++] = "pants" TAB "0 0 0.8 1";
	%node[%nodeCount++] = "LShoe" TAB "0.2 0.2 0.2 1";
	%node[%nodeCount++] = "RShoe" TAB "0.2 0.2 0.2 1";
	
	for(%i = 1; %i <= %nodeCount; %i++)
	{
		%av.unHideNode(%av.dynamicObject, getField(%node[%i], 0));
		%av.setNodeColor(%av.dynamicObject, getField(%node[%i], 0), getField(%node[%i], 1));
	}
	
	%av.setIflFrame(%av.dynamicObject, "face", 0);
	%av.setIflFrame(%av.dynamicObject, "decal", 0);
}

function CRPG_Vote::hideAllNodes(%gui, %id)
{
	if(!isObject(%av = "CRPG_Vote_Avatar_" @ %id))
		return false;
	
	%nodeCount = 0;
	
	%node[%nodeCount++] = "plume";
	%node[%nodeCount++] = "triPlume";
	%node[%nodeCount++] = "septPlume";
	%node[%nodeCount++] = "Visor";
	
	%node[%nodeCount++] = "helmet";
	%node[%nodeCount++] = "pointyHelmet";
	%node[%nodeCount++] = "flareHelmet";
	%node[%nodeCount++] = "scoutHat";
	%node[%nodeCount++] = "bicorn";
	%node[%nodeCount++] = "copHat";
	%node[%nodeCount++] = "knitHat";
	
	%node[%nodeCount++] = "chest";
	%node[%nodeCount++] = "femchest";
	
	%node[%nodeCount++] = "pants";
	%node[%nodeCount++] = "skirtHip";
	
	%node[%nodeCount++] = "armor";
	%node[%nodeCount++] = "bucket";
	%node[%nodeCount++] = "cape";
	%node[%nodeCount++] = "pack";
	%node[%nodeCount++] = "quiver";
	%node[%nodeCount++] = "tank";
	
	%node[%nodeCount++] = "epaulets";
	%node[%nodeCount++] = "epauletsRankA";
	%node[%nodeCount++] = "epauletsRankB";
	%node[%nodeCount++] = "epauletsRankC";
	%node[%nodeCount++] = "epauletsRankD";
	%node[%nodeCount++] = "ShoulderPads";
	
	%node[%nodeCount++] = "LArm";
	%node[%nodeCount++]  = "LArmSlim";
	
	%node[%nodeCount++]  = "LHand";
	%node[%nodeCount++]  = "LHook";
	
	%node[%nodeCount++]  = "RArm";
	%node[%nodeCount++]  = "RArmSlim";
	
	%node[%nodeCount++]  = "RHand";
	%node[%nodeCount++]  = "RHook";
	
	%node[%nodeCount++]  = "pants";
	%node[%nodeCount++]  = "skirtHip";
	
	%node[%nodeCount++]  = "LShoe";
	%node[%nodeCount++]  = "LPeg";
	
	%node[%nodeCount++]  = "RShoe";
	%node[%nodeCount++]  = "RPeg";
	
	%node[%nodeCount++]  = "SkirtTrimLeft";
	%node[%nodeCount++]  = "SkirtTrimRight";
	%node[%nodeCount++]  = "LSki";
	%node[%nodeCount++]  = "RSki";
	
	for(%i = 1; %i <= %nodeCount; %i++)
	{
		%av.hideNode(%av.dynamicObject, %node[%i]);
	}
}

function CRPG_Vote::initAvatars(%gui)
{
	for(%a = 1; %a <= 5; %a++)
	{
		%av = "CRPG_Vote_Avatar_" @ %a;
		%av.setEmpty();
		
		if(%av.parts > 0)
		{
			%av.dynamicObject = %av @ "_Object";
			%av.setObject(%av.dynamicObject, "base/data/shapes/player/m.dts", "", 0);
		}
		
		%gui.adjustAvatar(%a);
	}
}

function CRPG_Vote::onVote(%gui)
{
	if(%gui.selectedCandidate > 0)
	{
		CRPG_Vote_Button.setActive(false);
		
		%av = "CRPG_Vote_Avatar_" @ %gui.selectedCandidate;
		commandToServer('Vote_VoteFor', %av.bl_id);
	}
}

function CRPG_Vote::isCandidateActive(%gui, %id)
{
	if(!isObject(%av = "CRPG_Vote_Avatar_" @ %id))
		return false;
	
	return (%av.parts > 0);
}

function CRPG_Vote::onWake(%gui)
{
	CRPG_Vote.initAvatars();
}

function CRPG_Vote_Select::onMouseDown(%gui)
{
	if(!CRPG_Vote.isCandidateActive(%gui.candidate))
		return false;
	
	if(CRPG_Vote.selectedCandidate != %gui.candidate)
	{
		CRPG_Vote.selectedCandidate = %gui.candidate;
		
		%av = "CRPG_Vote_Avatar_" @ %gui.candidate;
		
		CRPG_Vote_Selection.setVisible(true);
		CRPG_Vote_Selection.position = (getWord(%av.position, 0) - 13) SPC "5";
		
		CRPG_Vote_Bitmap.setVisible(false);
		CRPG_Vote_Button.setVisible(true);
		
		return true;
	}
	
	return false;
}

// ============================================================
// Section 3 : ClientCmds
// ============================================================

function clientCmdVote_SetCandidate(%id, %bl_id, %name, %incumbent, %parts, %nodes, %colors, %decals, %accessories)
{
	if(!isObject(%av = "CRPG_Vote_Avatar_" @ %id))
		return false;
	
	if(%bl_id == -1)
		return false;
	
	%av.bl_id = %bl_id;
	%av.name = %name;
	%av.incumbent = %incumbent;
	
	%av.parts = %parts;
	%av.decal = getField(%decals, 0);
	%av.face = getField(%decals, 1);
	
	for(%i = 0; %i < %parts; %i++)
	{
		%av.part[%i] = getField(%nodes, %i);
		%av.color[%i] = getField(%colors, %i);
	}
	
	CRPG_Vote.hideAllNodes();
	CRPG_Vote.adjustAvatarNodes();
	CRPG_Vote.adjustAvatarColors();
}